%**************************************************************************
% Filename   : computeCanny.m
% Use        : cannyFrames = computeCanny(frames)
% Description: returns an array of frames where only edges are visualized: 
%                    -frames: frames of the movie.
%              output:
%                    -cannyFrames: frames with subject's edges for each
%                                  frame.
% Authors    : Marco Branca, Lorenzo Camerini
%**************************************************************************

function harrisFrames = computeHarris(frames, barHandler)

% Create a gaussian filter.
h_size=7;
sigma_gauss=2;
g = fspecial('gaussian',h_size,sigma_gauss);

% Create the differentiate filters.
dx=[-1 0 1; -1 0 1; -1 0 1];
dy=dx';

colorWaitbar(0, barHandler, 'Finding corners: please wait...');
harrisFrames = cast(zeros(size(frames(1).cdata,1), size(frames(1).cdata,2), length(frames)),'uint8');
numberOfFrames = length(frames);
for i = 1:numberOfFrames
    % Compute che horizonatal and vertical derivative.
    Ix=conv2(double(frames(i).cdata),dx,'same');
    Iy=conv2(double(frames(i).cdata),dy,'same');
    
    % Compute A,B,C for Harris' formula.
    A = conv2(Ix.^2, g, 'same');  
    B = conv2(Iy.^2, g, 'same');
    C = conv2(Ix.*Iy, g,'same');

    % Compute Harris.
    harrisFrames(:,:,i) = (A.*B-(C.^2))./(A+B+eps);
    colorWaitbar(i/(numberOfFrames*2), barHandler);
end

se = strel('disk',3);
for i = 1:numberOfFrames
    harrisFrames(:,:,i) = imclose(harrisFrames(:,:,i),se);
end

for i = 1:numberOfFrames
    L = bwlabel(harrisFrames(:,:,i));
    props = regionprops(L,'basic');
    centroid = cat(1, props.Centroid);    
    im_temp = zeros(size(harrisFrames(:,:,i),1), size(harrisFrames(:,:,i),2));    
    for j = 1: size(centroid,1)       
            im_temp(fix(centroid(j,2)),fix(centroid(j,1))) = 1;       
    end
    harrisFrames(:,:,i) = im_temp; 
    colorWaitbar((numberOfFrames+i)/(numberOfFrames*2), barHandler);
end

