%**************************************************************************
% Filename   : computeLastImage.m
% Use        : image = computeLastImage(lastFrame, mask, separatedBackFore)
% Description: returns an image with the mask added to the frame passed
%              as input parameter.
%              input: 
%                    - lastFrame: frame where the mask has to be added.
%                    - mask: mask to add to the image.
%		     - separatedBackFore: image with white pixel 
%                      corresponding to the part of the scene occupied by 
%                      the subject and black pixel in the part corresponding
%                      to the background.
%              output:
%                    - image: the image obtained by adding the mask to the 
%                      last frame of the movie.
% Authors    : Marco Branca, Lorenzo Camerini
%**************************************************************************
function image = computeLastImage(lastFrame, mask, separatedBackFore)

%compute the matrix that, added to the last frame, returns the white image
trackMatrix = cast(255*ones(size(lastFrame)),'uint8') - lastFrame;

%convert the mask and the separatesBackFore matrixes in RGB variables
trackRGB = cast(zeros(size(lastFrame)),'uint8');
separatedBackForeRGB = cast(zeros(size(lastFrame)),'uint8');
for channel = 1:3 
    trackRGB(:,:,channel) = mask; 
    separatedBackForeRGB(:,:,channel) =  separatedBackFore;
end

%computes a matrix composed of all zero, but stores the values needed to
%have white for pixels corresponding to the track
trackMatrix = trackMatrix.*cast(trackRGB,'uint8').*cast(~separatedBackForeRGB,'uint8');

%adds the track to the last image
image = lastFrame + trackMatrix;


