%**************************************************************************
% Filename   : envelope.m
% Description: compute the track of the moving object using the envelope
%              of the curve followed during the movement.
%              The results of the runned script are two:
%	           - an image representing the last frame of the movie with 
%                    the track of the whole movement.
%                  - a movie with, for each frame, the track of the last 
%                    k frames.
% Authors    : Marco Branca, Lorenzo Camerini
%**************************************************************************
switch dilateType
    case 'line' 
        se = strel(dilateType, data(1), data(2));
    case 'disk' 
        se = strel(dilateType,data);
end

%finds the edges in every frame
for i = 1:length(separatedBackFore)
    edges(:,:,i) = imdilate(edges(:,:,i), se);
end 

%computes for each couple of frames, the mask corresponding to the
%intersection of the subject's edges 
mask = cast(zeros(size(edges,1),size(edges,2),size(edges,3)-1), 'uint8');
for i = 1:length(separatedBackFore)-1
    mask(:,:,i) = edges(:,:,i) & edges(:,:,i+1);
end
track = mask(:,:,1);

%computes the whole track on the last frame
for i = 2:samplingRate:size(mask,3)-1
    track = track + mask(:,:,i);
end
track = track > 0;

%add the whole track to the last frame of the movie
envelopeLastFrame = computeLastImage(frames(end).cdata, track, separatedBackFore(end).cdata);

if transparencyValue == 0
    transparencyMatrix = ones(size(separatedBackFore(end).cdata));
else
    transparencyMatrix = computeLastImageTransparency(mask, separatedBackFore(end).cdata, 'envelope');
end

%add the computed track to each frame
addMaskToMovie;

%saves the results of the computation
%saveMovie(frameWithKTrack, [filename '_Envelope.avi']);
%saveImage(envelopeLastFrame, [filename '_EnvelopeLastFrame.jpg']);

%clears all unuseful variables
%clear frameWithKTrack envelopeLastFrame;
